@@ -14,7 +14,6 @@
 #    under the License.
 
 from http import client as http_client
-import json
 import socket
 import typing
 import urllib
@@ -38,6 +37,16 @@ LOG = logging.getLogger(__name__)
 _HOOKS_MGR = {}
 _OBJECT_NAME_PREFIX = 'inspector_data'
 AUTO_DISCOVERED_FLAG = 'auto_discovered'
+CALLBACK_API_ENDPOINT = '/continue_inspection'
+IPA_CALLBACK_PARAM = 'ipa-inspection-callback-url'
+
+
+def get_inspection_callback(ironic_url):
+    ironic_url = ironic_url.rstrip('/')
+    if ironic_url.endswith('/v1'):
+        return ironic_url + CALLBACK_API_ENDPOINT
+    else:
+        return f'{ironic_url}/v1{CALLBACK_API_ENDPOINT}'
 
 
 def create_ports_if_not_exist(task, macs=None):
@@ -165,8 +174,6 @@ def get_inspection_data(node, context):
     :raises: NodeInventoryNotFound if no inventory has been saved
     """
     store_data = CONF.inventory.data_backend
-    if store_data == 'none':
-        raise exception.NodeInventoryNotFound(node=node.uuid)
     if store_data == 'database':
         node_inventory = objects.NodeInventory.get_by_node_id(
             context, node.id)
@@ -177,6 +184,8 @@ def get_inspection_data(node, context):
             return _get_inspection_data_from_swift(node.uuid)
         except exception.SwiftObjectNotFoundError:
             raise exception.NodeInventoryNotFound(node=node.uuid)
+    # all other cases should not return any data
+    raise exception.NodeInventoryNotFound(node=node.uuid)
 
 
 def _store_inspection_data_in_swift(node_uuid, inventory_data, plugin_data):
@@ -190,10 +199,10 @@ def _store_inspection_data_in_swift(node_uuid, inventory_data, plugin_data):
     swift_object_name = f'{_OBJECT_NAME_PREFIX}-{node_uuid}'
     container = CONF.inventory.swift_data_container
     swift_api.create_object_from_data(f'{swift_object_name}-inventory',
-                                      json.dumps(inventory_data),
+                                      inventory_data,
                                       container)
     swift_api.create_object_from_data(f'{swift_object_name}-plugin',
-                                      json.dumps(plugin_data),
+                                      plugin_data,
                                       container)
     return swift_object_name
 
