@@ -678,6 +678,23 @@ class FileImageServiceTestCase(base.TestCase):
                           self.service.validate_href, self.href)
         path_exists_mock.assert_called_once_with(self.href_path)
 
+    @mock.patch.object(os.path, 'abspath', autospec=True)
+    def test_validate_href_blocked_path(self, abspath_mock):
+        href = 'file:///dev/sda1'
+        href_path = '/dev/sda1'
+        href_dir = '/dev'
+        abspath_mock.side_effect = [href_dir, href_path]
+        # Explicitly allow the bad path
+        cfg.CONF.set_override('file_url_allowed_paths', [href_dir],
+                              'conductor')
+
+        # Still raises an error because /dev is expressly forbidden
+        self.assertRaisesRegex(exception.ImageRefValidationFailed,
+                               "is not permitted in file URLs",
+                               self.service.validate_href, href)
+        abspath_mock.assert_has_calls(
+            [mock.call(href_dir), mock.call(href_path)])
+
     @mock.patch.object(os.path, 'abspath', autospec=True)
     def test_validate_href_empty_allowlist(self, abspath_mock):
         abspath_mock.return_value = self.href_path
